@@ -17,7 +17,8 @@
 # under the License.
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Sequence
+from collections.abc import Sequence
+from typing import TYPE_CHECKING
 
 from airflow.io.path import ObjectStoragePath
 from airflow.models import BaseOperator
@@ -75,8 +76,7 @@ class FileTransferOperator(BaseOperator):
         src.copy(dst)
 
     def get_openlineage_facets_on_start(self) -> OperatorLineage:
-        from openlineage.client.run import Dataset
-
+        from airflow.providers.common.compat.openlineage.facet import Dataset
         from airflow.providers.openlineage.extractors import OperatorLineage
 
         def _prepare_ol_dataset(path: ObjectStoragePath) -> Dataset:
